@@ -123,9 +123,12 @@ def post_value():
             if options.get('configuration'):
                 configuration = options.get('configuration')
                 env = configuration.get('env')
+                hosting = configuration.get('hosting')
         if env == 'qa':
             os.environ['ROLLOUT_MODE'] = 'QA'
-        options = RoxOptions(logger=ServerLogger())
+        if env == 'localhost':
+            os.environ['ROLLOUT_MODE'] = 'LOCAL'
+        options = RoxOptions(logger=ServerLogger(), hosting=hosting)
         cancel_event = Rox.setup(payload['key'], options).result()
         return jsonify({ 'result': 'done' })
     elif action == 'stop':
