@@ -60,7 +60,7 @@ class Environment:
         elif rollout_mode == 'LOCAL':
             return Environment.PATHS['LOCAL']['API_PATH']
         
-        if server_url is not 'https://x-api.rollout.io':
+        if server_url != 'https://x-api.rollout.io':
             Environment.PATHS['DEFAULT']['API_PATH'] = '%s/device/get_configuration' % server_url
         return Environment.PATHS['DEFAULT']['API_PATH']
 
@@ -82,7 +82,7 @@ class Environment:
         elif rollout_mode == 'LOCAL':
             return Environment.PATHS['LOCAL']['API_STATE_PATH']
 
-        if server_url is not 'https://x-api.rollout.io':
+        if server_url != 'https://x-api.rollout.io':
             Environment.PATHS['DEFAULT']['API_STATE_PATH'] = '%s/device/update_state_store' % server_url
         return Environment.PATHS['DEFAULT']['API_STATE_PATH']
 
@@ -116,7 +116,7 @@ class Environment:
 
     @staticmethod
     def SWITCH_TO_REGION_HOSTING(hosting):
-        if hosting is 'eu':
+        if hosting == 'eu':
             Environment.PATHS['QA']['API_PATH'] = Environment.ADD_PREFIX_TO_URL(hosting, Environment.PATHS['QA']['API_PATH'])
             Environment.PATHS['DEFAULT']['API_PATH'] = Environment.ADD_PREFIX_TO_URL(hosting, Environment.PATHS['DEFAULT']['API_PATH'])
             Environment.PATHS['QA']['API_STATE_PATH'] = Environment.ADD_PREFIX_TO_URL(hosting, Environment.PATHS['QA']['API_STATE_PATH'])
