@@ -11,12 +11,17 @@ class UserspaceUnhandledErrorInvoker:
         
         try:
             self.user_unhandler_error_handler(UserspaceUnhandledErrorArgs(exception_source, exception_trigger, exception))
-        except Exception:
-            Logging.get_logger().error('User Unhandled Error Handler itself threw an exception. original exception: {}'.format(exception))
+        except Exception as handler_exception:
+            Logging.get_logger().error(
+                'User Unhandled Error Handler itself threw an exception. Unhandled Error Handler exception: {}. Original exception: {}'.format(handler_exception, exception)
+            )
 
     def set_handler(self, handler):
         self.user_unhandler_error_handler = handler
 
+
+# Container object to be passed to user error handler.
+# Wraps the parameters to make it easier to add new ones in the future whilst preserving backward compatibility because the function args don't change.
 class UserspaceUnhandledErrorArgs:
     def __init__(self, exception_source=None, exception_trigger=None, exception=None):
         self.exception_source = exception_source
@@ -27,4 +32,4 @@ class UserspaceUnhandledErrorArgs:
         return 'UserspaceUnhandledErrorArgs({}, {}, {})'.format(self.exception_source, self.exception_trigger, self.exception)
 
     def __str__(self):
-        return 'UserspaceUnhandledErrorArgs({}, {}, {})'.format(self.exception_source, self.exception_trigger, self.exception)
\ No newline at end of file
+        return 'UserspaceUnhandledErrorArgs({}, {}, {})'.format(self.exception_source, self.exception_trigger, self.exception)
